/* atoms_covalent.inc - covalent radii used by atoms.inc */
/* from Pauling and CAChe S/W */
/* 5/4/94 -egs- */

#declare N_RAD = 0.74
#declare C_RAD = 0.77
#declare O_RAD = 0.73
#declare P_RAD = 1.10
#declare S_RAD = 1.04
#declare CA_RAD =1.74
#declare H_RAD = .35
#declare FE_RAD = 1.17
