/* atoms_cpk.inc - CPK radii for atoms, used by atoms.inc */


#declare N_RAD = 1.54
#declare C_RAD = 1.7
#declare O_RAD = 1.4
#declare P_RAD = 1.9
#declare S_RAD = 1.8
#declare CA_RAD = 1.274
#declare H_RAD = 1.2
#declare FE_RAD = 2.0

